diff dvdnav_events.h @ 55:5674fbd44f26 src

report all spu types (widescreen, letterbox and pan&scan), not widescreen only and report the stream's scale permissions to detect pan&scan material
author mroi
date Fri, 05 Jul 2002 14:18:55 +0000
parents 0ba15bf3dc25
children b6834e6359cf
line wrap: on
line diff
--- a/dvdnav_events.h	Fri Jul 05 01:42:30 2002 +0000
+++ b/dvdnav_events.h	Fri Jul 05 14:18:55 2002 +0000
@@ -64,12 +64,22 @@
 } dvdnav_still_event_t;
 
 /**
- * Structure providing information on DVDNAV_*_STREAM_CHANGE events.
+ * Structure providing information on DVDNAV_SPU_STREAM_CHANGE events.
+ */
+typedef struct {
+  int physical_wide; /*!< The physical (MPEG) stream number for widescreen display. */
+  int physical_letterbox; /*!< The physical (MPEG) stream number for letterboxed display. */
+  int physical_pan_scan; /*!< The physical (MPEG) stream number for pan&scan display. */
+  int logical;  /*!< The logical (DVD) stream number.   */
+} dvdnav_spu_stream_change_event_t;
+
+/**
+ * Structure providing information on DVDNAV_AUDIO_STREAM_CHANGE events.
  */
 typedef struct {
   int physical; /*!< The physical (MPEG) stream number. */
   int logical;  /*!< The logical (DVD) stream number.   */
-} dvdnav_stream_change_event_t;
+} dvdnav_audio_stream_change_event_t;
 
 /**
  * Structure providing information on DVDNAV_VTS_CHANGE events.